'''
Created on Dec, 2016

@author: jwi

This script performs an energy balance decomposition of local effects in the MPI-ESM.
For conversion of all three surface properties, only surface albedo and only surface roughness.

'''
import os
import numpy as np
import xarray as xr
from copy import deepcopy as cp

#data analysis

#import sys
#import imp
#imp.reload(sys.modules['separate_local_nonlocal3'])
from separate_local_nonlocal3 import separate_local_nonlocal
from Sealandmask_lat_lon import Sealandmask_lat_lon
from scipy.interpolate import griddata

#plot
import pickle #for importing colorbar
import matplotlib as mpl
import matplotlib.pyplot as plt
from matplotlib import gridspec
from mpl_toolkits.basemap import Basemap
from mpl_toolkits import basemap
from mpl_toolkits.basemap import interp
import numpy.ma as ma
#

#imp.reload(sys.modules['Sealandmask_lat_lon'])

'''
--- SECTION 1: load netcdf data (model)------------------------------------------------------------------------------------------
'''
#local effects in model (from 3of4 simulation)
varnames=['var169','var146','var147','var176', 'var204', 'var177','var205','var204','var175']
timespan='2000-2199'
#idir='/scratch/local1/m300344/PowerFolders/paper03/data/'
idir='~/paper_jwi/2017_paper03/data/'
data1={}
expids=['jwi0048_1','jwi0044_2','jwi0053_1','jwi0043_1']
for varname in varnames:
    for expid in expids:
        data1[expid+'_'+varname]=np.squeeze(xr.open_dataset(idir+'selcode_'+expid+'_echam6_BOT_timmean_'+timespan+'.nc')[varname])
    data1['3of4'+'_'+varname]=data1['jwi0044_2'+'_'+varname].values-data1['jwi0048_1'+'_'+varname].values
    data1['z0'+'_'+varname]=data1['jwi0053_1'+'_'+varname].values-data1['jwi0048_1'+'_'+varname].values
    data1['albedo'+'_'+varname]=data1['jwi0043_1'+'_'+varname].values-data1['jwi0048_1'+'_'+varname].values

#%%
'''
--- SECTION 2: separate local from non-local effects----------------------------------------------------------------------
'''
lcc_patterns=['3of4']

local={}
local_interped={}
nonlocal={}
for varname in varnames:
    for lcc_pattern in lcc_patterns:
        local_interped[lcc_pattern+'_'+varname],local[lcc_pattern+'_'+varname],nonlocal[lcc_pattern+'_'+varname]=np.zeros((96, 192)),np.zeros((96, 192)),np.zeros((96, 192))
        local_interped[lcc_pattern+'_'+varname],local[lcc_pattern+'_'+varname],nonlocal[lcc_pattern+'_'+varname]=separate_local_nonlocal(data1[lcc_pattern+'_'+varname], lcc_pattern)
        local_interped['z0_'+varname],local['z0_'+varname],nonlocal['z0_'+varname]=np.zeros((96, 192)),np.zeros((96, 192)),np.zeros((96, 192))
        local_interped['z0_'+varname],local['z0_'+varname],nonlocal['z0_'+varname]=separate_local_nonlocal(data1['z0_'+varname], lcc_pattern)
        local_interped['albedo_'+varname],local['albedo_'+varname],nonlocal['albedo_'+varname]=np.zeros((96, 192)),np.zeros((96, 192)),np.zeros((96, 192))
        local_interped['albedo_'+varname],local['albedo_'+varname],nonlocal['albedo_'+varname]=separate_local_nonlocal(data1['albedo_'+varname], lcc_pattern)

local_interped['3of4_var175']=cp(local_interped['3of4'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 
nonlocal['3of4_var175']=cp(nonlocal['3of4'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 

local_interped['z0_var175']=cp(local_interped['z0'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 
nonlocal['3of4_var175']=cp(nonlocal['3of4'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 

local_interped['albedo_var175']=cp(local_interped['albedo'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 
nonlocal['3of4_var175']=cp(nonlocal['3of4'+'_var175'])*(data1['jwi0048_1'+'_var176'].values-data1['jwi0048_1'+'_var204'].values) 

#%%
'''
--- SECTION 3: Convert energy balance components into delta_Tsurf[K] ------------------------------------------------------------------------------------------
'''
#factor=-1/(4*5.67e-8*data1['jwi0048_1'+'_'+varname].values*data1['jwi0048_1'+'_'+varname].values*data1['jwi0048_1'+'_'+varname].values)
factor1=-1/(5.67e-8*4*(data1['jwi0048_1'+'_var169'].values)**3)
for varname in varnames:
    local_interped['3of4'+'_'+varname+'_K'],local['3of4'+'_'+varname+'_K'],nonlocal['3of4'+'_'+varname+'_K']=factor1*(local_interped['3of4'+'_'+varname],local['3of4'+'_'+varname],nonlocal['3of4'+'_'+varname])
    local_interped['z0'+'_'+varname+'_K'],local['z0'+'_'+varname+'_K'],nonlocal['z0'+'_'+varname+'_K']=factor1*(local_interped['z0'+'_'+varname],local['z0'+'_'+varname],nonlocal['z0'+'_'+varname])
    local_interped['albedo'+'_'+varname+'_K'],local['albedo'+'_'+varname+'_K'],nonlocal['albedo'+'_'+varname+'_K']=factor1*(local_interped['albedo'+'_'+varname],local['albedo'+'_'+varname],nonlocal['albedo'+'_'+varname])

if False:
    fig = plt.figure()
    plt.subplot(2,2,1)
    plt.imshow(slm1,vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,3)
    plt.imshow(local_interped['3of4_var176_K']+local_interped['3of4_var177_K']+local_interped['3of4_var205_K']+local_interped['3of4_var146_K']+local_interped['3of4_var147_K'],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,2)
    plt.imshow(data1['jwi0048_1'+'_var204'], interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,4)
    plt.imshow(data1['jwi0048_1'+'_var176'], interpolation= 'None')
    plt.colorbar()
    plt.show()

#%%
'''
--- SECTION 4: Latitudinal means ------------------------------------------------------------------------------------------
'''
slm,lat,lon,slm1=Sealandmask_lat_lon().slm,Sealandmask_lat_lon().lat,Sealandmask_lat_lon().lon,Sealandmask_lat_lon().slm1

        
data_masked={}
for exp in ['3of4','z0','albedo']:
    for varname in varnames:
        data_masked[exp+'_local_'+varname]=cp(local_interped[exp+'_'+varname+'_K']) 
        data_masked[exp+'_nonlocal_'+varname]=cp(nonlocal[exp+'_'+varname+'_K'])   
    data_masked[exp+'_local_var169']=cp(local_interped[exp+'_var169']) 
    data_masked[exp+'_nonlocal_var169']=cp(nonlocal[exp+'_var169'])    

#mask values using the observations mask, and average only where values are available there.
obs_mask=np.load('/home/jwi/paper_jwi/2017_paper03/data/observations/obs_mask.npy')
for kk in data_masked.keys():
    #data_masked[kk][slm1!=1]=np.nan
    data_masked[kk][obs_mask==0]=np.nan
    
latitudinal={}
latitudinal1={}
for exp in ['3of4','z0','albedo']:
    for varname in varnames:
        latitudinal[exp+'_local_'+varname]=np.nanmean(data_masked[exp+'_local_'+varname],axis=1)
        latitudinal[exp+'_nonlocal_'+varname]=np.nanmean(data_masked[exp+'_nonlocal_'+varname],axis=1)
        latitudinal1[exp+'_local_'+varname]=np.nanmean(local_interped[exp+'_'+varname+'_K'],axis=1)
        latitudinal1[exp+'_nonlocal_'+varname]=np.nanmean(nonlocal[exp+'_'+varname+'_K'],axis=1)
    latitudinal[exp+'_local_sw_in']=-np.nanmean((1-data1['jwi0048_1'+'_var175'].values)*(data_masked[exp+'_local_var176']-data_masked[exp+'_local_var204']),axis=1)
    latitudinal[exp+'_nonlocal_sw_in']=-np.nanmean((1-data1['jwi0048_1'+'_var175'].values)*(data_masked[exp+'_nonlocal_var176']-data_masked[exp+'_nonlocal_var204']),axis=1)
    latitudinal1[exp+'_local_sw_in']=-np.nanmean((1-data1['jwi0048_1'+'_var175'].values)*(local_interped[exp+'_var176']-local_interped[exp+'_var204']),axis=1)
    latitudinal1[exp+'_nonlocal_sw_in']=-np.nanmean((1-data1['jwi0048_1'+'_var175'].values)*(nonlocal[exp+'_var176']-nonlocal[exp+'_var204']),axis=1)
    
    
#%%
'''
--- SECTION 5: save data ------------------------------------------------------------------------------------------
'''
np.save('/home/jwi/paper_jwi/2018_paper05/data/save/latitudinal_ebd',latitudinal)

    
#%%
'''
--- SECTION 6: PLOT ------------------------------------------------------------------------------------------
'''

#Energy balance decomposition
fig = plt.figure(figsize=(36,20))
gs= gridspec.GridSpec(1, 4, width_ratios=(5,5,5,3.9))
#
axes = plt.subplot(gs[0,0])

plt.plot(-latitudinal['3of4_'+'local_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['3of4_'+'local_var177']+latitudinal['3of4_'+'local_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['3of4_'+'local_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['3of4_'+'local_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['3of4_'+'local_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=0, c='grey',zorder=0)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
local_text=axes.set_title('a) all \n ',fontsize=40)
local_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
plt.ylabel('latitude ',fontsize=40)
#plt.ylabel('latitude [$^{\circ}$]',fontsize=40)

#
axes = plt.subplot(gs[0,1])

plt.plot(-latitudinal['z0_'+'local_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['z0_'+'local_var177']+latitudinal['z0_'+'local_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['z0_'+'local_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['z0_'+'local_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['z0_'+'local_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=0, c='grey',zorder=0)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
local_text=axes.set_title('b) only roughness \n ',fontsize=40)
local_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)


#
axes = plt.subplot(gs[0,2])
plt.plot(-latitudinal['albedo_'+'local_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['albedo_'+'local_var177']+latitudinal['albedo_'+'local_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['albedo_'+'local_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['albedo_'+'local_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['albedo_'+'local_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=0, c='grey',zorder=0)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
local_text=axes.set_title('c) only surface albedo \n ',fontsize=40)
local_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )

h,l = axes.get_legend_handles_labels()
laxes = plt.subplot(gs[0,3])
laxes.legend(h,l, borderaxespad=0, fontsize=40)
laxes.axis("off")

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/energy_balance_decomposition_obs_mask_z0_albedo_onlylocal.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/energy_balance_decomposition_obs_mask_z0_albedo_onlylocal.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=300, bbox_inches='tight')
os.system('pdfcrop ' +pdffile +' '+pdffile)

plt.close()



#%% same for nonlocal effects

#Energy balance decomposition
fig = plt.figure(figsize=(36,20))
gs= gridspec.GridSpec(1, 4, width_ratios=(5,5,5,3.8))
#
axes = plt.subplot(gs[0,0])

plt.plot(-latitudinal['3of4_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['3of4_'+'nonlocal_var177']+latitudinal['3of4_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['3of4_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['3of4_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['3of4_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('a) all  \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
plt.ylabel('latitude ',fontsize=40)
#plt.ylabel('latitude [$^{\circ}$]',fontsize=40)

#
axes = plt.subplot(gs[0,1])
plt.plot(-latitudinal['z0_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['z0_'+'nonlocal_var177']+latitudinal['z0_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['z0_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['z0_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['z0_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('b) only roughness \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)


#
axes = plt.subplot(gs[0,2])
plt.plot(-latitudinal['albedo_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['albedo_'+'nonlocal_var177']+latitudinal['albedo_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['albedo_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['albedo_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['albedo_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-3,5))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('c) only surface albedo \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)

laxes = plt.subplot(gs[0,3])
laxes.legend(h,l, borderaxespad=0, fontsize=40)
laxes.axis("off")

plt.tight_layout()

pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/energy_balance_decomposition_obs_mask_z0_albedo_onlynonlocal.pdf'
fig.savefig(pdffile,dpi=300, bbox_inches='tight')
os.system('pdfcrop ' +pdffile +' '+pdffile)

plt.close()


#%% same for nonlocal effects

#Energy balance decomposition
fig = plt.figure(figsize=(36,40))
gs= gridspec.GridSpec(2, 4, width_ratios=(5,5,5,3.8))
#
axes = plt.subplot(gs[0,0])

plt.plot(-latitudinal['3of4_'+'local_var176']-latitudinal['3of4_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['3of4_'+'local_var177']+latitudinal['3of4_'+'local_var205']-latitudinal['3of4_'+'nonlocal_var177']+latitudinal['3of4_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['3of4_'+'local_var146']-latitudinal['3of4_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['3of4_'+'local_var147']-latitudinal['3of4_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['3of4_'+'local_var169']+latitudinal['3of4_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('a) all  \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
plt.ylabel('latitude ',fontsize=40)
#plt.ylabel('latitude [$^{\circ}$]',fontsize=40)

#
axes = plt.subplot(gs[0,1])
plt.plot(-latitudinal['z0_'+'local_var176']-latitudinal['z0_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['z0_'+'local_var177']+latitudinal['z0_'+'local_var205']-latitudinal['z0_'+'nonlocal_var177']+latitudinal['z0_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['z0_'+'local_var146']-latitudinal['z0_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['z0_'+'local_var147']-latitudinal['z0_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['z0_'+'local_var169']+latitudinal['z0_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('b) only roughness \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)


#
axes = plt.subplot(gs[0,2])
plt.plot(-latitudinal['albedo_'+'local_var176']-latitudinal['albedo_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal['albedo_'+'local_var177']+latitudinal['albedo_'+'local_var205']-latitudinal['albedo_'+'nonlocal_var177']+latitudinal['albedo_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal['albedo_'+'local_var146']-latitudinal['albedo_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal['albedo_'+'local_var147']-latitudinal['albedo_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(latitudinal['albedo_'+'local_var169']+latitudinal['albedo_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('c) only surface albedo \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)


#all longitudes
axes = plt.subplot(gs[1,0])

plt.plot(-latitudinal1['3of4_'+'local_var176']-latitudinal1['3of4_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal1['3of4_'+'local_var177']+latitudinal1['3of4_'+'local_var205']-latitudinal1['3of4_'+'nonlocal_var177']+latitudinal1['3of4_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal1['3of4_'+'local_var146']-latitudinal1['3of4_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal1['3of4_'+'local_var147']-latitudinal1['3of4_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(-latitudinal1['3of4_'+'local_var169']-latitudinal1['3of4_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('d) \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
plt.ylabel('latitude ',fontsize=40)
#plt.ylabel('latitude [$^{\circ}$]',fontsize=40)

#
axes = plt.subplot(gs[1,1])
plt.plot(-latitudinal1['z0_'+'local_var176']-latitudinal1['z0_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal1['z0_'+'local_var177']+latitudinal1['z0_'+'local_var205']-latitudinal1['z0_'+'nonlocal_var177']+latitudinal1['z0_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal1['z0_'+'local_var146']-latitudinal1['z0_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal1['z0_'+'local_var147']-latitudinal1['z0_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(-latitudinal1['z0_'+'local_var169']-latitudinal1['z0_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('e)  \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)


#
axes = plt.subplot(gs[1,2])
plt.plot(-latitudinal1['albedo_'+'local_var176']-latitudinal1['albedo_'+'nonlocal_var176'],lat,label='net shortwave',linewidth=4, color='red')
plt.plot(-latitudinal1['albedo_'+'local_var177']+latitudinal1['albedo_'+'local_var205']-latitudinal1['albedo_'+'nonlocal_var177']+latitudinal1['albedo_'+'nonlocal_var205'],lat,label='incoming longwave',linewidth=4, color='orange')
plt.plot(-latitudinal1['albedo_'+'local_var146']-latitudinal1['albedo_'+'nonlocal_var146'],lat,label='sensible',linewidth=4, color='c', alpha=0.6)
plt.plot(-latitudinal1['albedo_'+'local_var147']-latitudinal1['albedo_'+'nonlocal_var147'],lat,label='latent',linewidth=4, color='blue')

plt.plot(-latitudinal1['albedo_'+'local_var169']-latitudinal1['albedo_'+'nonlocal_var169'],lat,label='$T_{surf}$',linewidth=8, color='black')
#test=-latitudinal1['albedo_'+'local_var176']-latitudinal1['albedo_'+'nonlocal_var176']-latitudinal1['albedo_'+'local_var177']+latitudinal1['albedo_'+'local_var205']-latitudinal1['albedo_'+'nonlocal_var177']+latitudinal1['albedo_'+'nonlocal_var205']-latitudinal1['albedo_'+'local_var146']-latitudinal1['albedo_'+'nonlocal_var146']-latitudinal1['albedo_'+'local_var147']-latitudinal1['albedo_'+'nonlocal_var147']
#plt.plot(test,lat,label='$T_{surf}$',linewidth=8, color='black')

plt.ylim((-39,71.82))
plt.xlim((-4,4))
plt.xticks(fontsize=40)
plt.yticks(fontsize=40)
plt.axvline(x=-3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=-1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=1, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=2, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=3, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=4, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=5, c='lightgrey',zorder=0, linewidth=0.5)
plt.axvline(x=0, c='grey',zorder=0)
nonlocal_text=axes.set_title('f) \n ',fontsize=40)
nonlocal_text.set_verticalalignment('center')
plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=40 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=40)

laxes = plt.subplot(gs[0,3])
laxes.legend(h,l, borderaxespad=0, fontsize=40)
laxes.axis("off")

plt.tight_layout()

pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/energy_balance_decomposition_obs_mask_z0_albedo_local_and_nonlocal01.pdf'
fig.savefig(pdffile,dpi=300, bbox_inches='tight')
os.system('pdfcrop ' +pdffile +' '+pdffile)

plt.close()
