'''
Created on Dec, 2016

@author: jwi

This script compares the local effects of MPI-ESM to different observation-based datasets.

DATASETS:
----------------
MPI-ESM:
-2of4
-mask values where veg_ratio_max<0.5

Alkama:
-regrid to T63 resolution
-take only values where deforestation in the observation time frame was larger than 1%
(-mask values where JSBACH's veg_ratio_max<0.5)

Li:
-regrid to T63 resolution

Bright:
-regrid to T63 resolution
-weight the three types according to the ratios of the PFTs in the jsbach.nc file.


Data processing for latitudinal plots:
----------------
-Take latitudinal mean over all values that are available in the respective datasets. 
-smooth the latitudinal curves a bit (value_new[ii]=(0.5*value_old[ii-1]+value_old[ii]+0.5*value_old[ii+1])/2). 
'''
import os
import numpy as np
import xarray as xr
from copy import deepcopy as cp

#data analysis
from separate_local_nonlocal3 import separate_local_nonlocal
from Sealandmask_lat_lon import Sealandmask_lat_lon
from scipy.interpolate import griddata
import mpl_toolkits

#plot
import pickle #for importing colorbar
import matplotlib as mpl
import matplotlib.pyplot as plt
from matplotlib import gridspec
from mpl_toolkits.basemap import Basemap
from mpl_toolkits import basemap
import numpy.ma as ma
#
#%%
'''
--- SECTION 1: load netcdf data (model)------------------------------------------------------------------------------------------
'''
#local effects in model (from 3of4 simulation)
varname='var169'
timespan='2000-2099'
#idir='/scratch/local1/m300344/PowerFolders/paper03/data/'
idir='~/paper_jwi/2017_paper03/data/'
data1={}
expids=['jwi0048_1','jwi0044_2','jwi0053_1','jwi0043_1']
varnames=['var218','var219','var169']
for var in varnames:
    for expid in expids:
        data1[expid+'_'+var]=np.squeeze(xr.open_dataset(idir+'selcode_'+expid+'_echam6_BOT_yseasmean_'+timespan+'.nc')[var])
    data1['3of4'+'_'+var]=data1['jwi0044_2'+'_'+var].values-data1['jwi0048_1'+'_'+var].values
    data1['only_z0'+'_'+var]=data1['jwi0053_1'+'_'+var].values-data1['jwi0048_1'+'_'+var].values
    data1['only_albedo'+'_'+var]=data1['jwi0043_1'+'_'+var].values-data1['jwi0048_1'+'_'+var].values

#%%
'''
--- SECTION 2: separate local from non-local effects----------------------------------------------------------------------
'''
params=['3of4', 'only_z0', 'only_albedo']

local={}
local_interped={}
nonlocal={}

for pp in params:
    for var in varnames:
        local_interped[pp+'_'+var],local[pp+'_'+var],nonlocal[pp+'_'+var]=np.zeros((4, 96, 192)),np.zeros((4, 96, 192)),np.zeros((4, 96, 192))
        for ii in np.arange(4):
            local_interped[pp+'_'+var+'_'+np.str(ii)],local[pp+'_'+var+'_'+np.str(ii)],nonlocal[pp+'_'+var+'_'+np.str(ii)]=separate_local_nonlocal(data1[pp+'_'+var][ii], '3of4')
        local_interped[pp+'_'+var+'_JJA']=local_interped[pp+'_'+var+'_2']
        local_interped[pp+'_'+var+'_DJF']=local_interped[pp+'_'+var+'_0']

    local_interped[pp+'_diurnal']=np.nanmean(np.array((local_interped[pp+'_var218_0'],local_interped[pp+'_var218_1'],local_interped[pp+'_var218_2'],local_interped[pp+'_var218_3']))-np.array((local_interped[pp+'_var219_0'],local_interped[pp+'_var219_1'],local_interped[pp+'_var219_2'],local_interped[pp+'_var219_3'])),axis=0)
    local_interped[pp+'_mean']=np.nanmean(np.array((local_interped[pp+'_var169_0'],local_interped[pp+'_var169_1'],local_interped[pp+'_var169_2'],local_interped[pp+'_var169_3'])),axis=0)

slm,lat,lon,slm1=Sealandmask_lat_lon().slm,Sealandmask_lat_lon().lat,Sealandmask_lat_lon().lon,Sealandmask_lat_lon().slm1


#%%
'''
--- SECTION 3: load netcdf data (observations) and process for plotting------------------------------------------------------------------------------------------
'''
vrm=xr.open_dataset(idir+'jsbach_T63GR15_11tiles_5layers_1850_sparse_TC1.0.nc')['veg_ratio_max']

regridded={}
#ALKAMA------------------------------------------------------------
#load data
alkama_JJA,alkama_mean,alkama_DJF,alkama_diurnal,alkama_forestloss=np.zeros((45,90)),np.zeros((45,90)),np.zeros((45,90)),np.zeros((45,90)),np.zeros((45,90))

alkama1_mean=xr.open_dataset(idir+'observations/Alkama_figureS07.nc')['Annual_mean'][::-1,:]
alkama1_JJA=xr.open_dataset(idir+'observations/Alkama_figureS07.nc')['Summer'][::-1,:]
alkama1_DJF=xr.open_dataset(idir+'observations/Alkama_figureS07.nc')['Winter'][::-1,:]
alkama1_diurnal=xr.open_dataset(idir+'observations/Alkama_figureS07.nc')['Daily_amplitude'][::-1,:]
alkama_forestloss1=xr.open_dataset(idir+'observations/Alkama_figureS07.nc')['forest_loss'][::-1,:]
alkama_JJA[3:37,:],alkama_DJF[3:37,:],alkama_forestloss[3:37,:]=cp(alkama1_JJA),cp(alkama1_DJF),cp(alkama_forestloss1)
alkama_mean[3:37,:]=cp(alkama1_mean)
alkama_diurnal[3:37,:],alkama_forestloss[3:37,:]=cp(alkama1_diurnal),cp(alkama_forestloss1)

#regridding alkama
threshold=1 #in percent deforested area
points=np.where(np.ones(alkama_JJA.shape))
values_mean,values_JJA, values_DJF, values_diurnal, values_forestloss=[],[],[],[],[]

for ii in np.arange(len(points[0])):
    values_JJA.append(alkama_JJA[points[0][ii],points[1][ii]])
    values_DJF.append(alkama_DJF[points[0][ii],points[1][ii]])
    values_diurnal.append(alkama_diurnal[points[0][ii],points[1][ii]])
    values_mean.append(alkama_mean[points[0][ii],points[1][ii]])
    values_forestloss.append(alkama_forestloss[points[0][ii],points[1][ii]])
grid_x, grid_y = np.mgrid[0:96:1, 0:192:1]
interped_JJA=griddata(np.array((points[1]*192/alkama_JJA.shape[1], points[0]*96/alkama_JJA.shape[0])).T, values_JJA,  (grid_y,grid_x), method='linear')
interped_DJF=griddata(np.array((points[1]*192/alkama_DJF.shape[1], points[0]*96/alkama_DJF.shape[0])).T, values_DJF,  (grid_y,grid_x), method='linear')
interped_mean=griddata(np.array((points[1]*192/alkama_mean.shape[1], points[0]*96/alkama_mean.shape[0])).T, values_mean,  (grid_y,grid_x), method='linear')
interped_diurnal=griddata(np.array((points[1]*192/alkama_diurnal.shape[1], points[0]*96/alkama_diurnal.shape[0])).T, values_diurnal,  (grid_y,grid_x), method='linear')
interped_forestloss=griddata(np.array((points[1]*192/alkama_DJF.shape[1], points[0]*96/alkama_DJF.shape[0])).T, values_forestloss,  (grid_y,grid_x), method='linear')

regridded['alkama_JJA']=cp(interped_JJA)
regridded['alkama_JJA'][interped_forestloss<threshold]=np.nan
regridded['alkama_JJA']=ma.masked_invalid(regridded['alkama_JJA'])
regridded['alkama_JJA'],lon_shifted=basemap.shiftgrid(180,regridded['alkama_JJA'],lonsin=Sealandmask_lat_lon().lon)

regridded['alkama_DJF']=cp(interped_DJF)
regridded['alkama_DJF'][interped_forestloss<threshold]=np.nan
regridded['alkama_DJF']=ma.masked_invalid(regridded['alkama_DJF'])
regridded['alkama_DJF'],lon_shifted=basemap.shiftgrid(180,regridded['alkama_DJF'],lonsin=Sealandmask_lat_lon().lon)

regridded['alkama_mean']=cp(interped_mean)
regridded['alkama_mean'][interped_forestloss<threshold]=np.nan
regridded['alkama_mean']=ma.masked_invalid(regridded['alkama_mean'])
regridded['alkama_mean'],lon_shifted=basemap.shiftgrid(180,regridded['alkama_mean'],lonsin=Sealandmask_lat_lon().lon)

regridded['alkama_diurnal']=cp(interped_diurnal)
regridded['alkama_diurnal'][interped_forestloss<threshold]=np.nan
regridded['alkama_diurnal']=ma.masked_invalid(regridded['alkama_diurnal'])
regridded['alkama_diurnal'],lon_shifted=basemap.shiftgrid(180,regridded['alkama_diurnal'],lonsin=Sealandmask_lat_lon().lon)

interped_forestloss,lon_shifted=basemap.shiftgrid(180,interped_forestloss,lonsin=Sealandmask_lat_lon().lon)
#%%

##BRIGHT------------------------------------------------------------#
bright_transitions=['EBF2GRA','EBF2GRA','DBF2GRA','ENF2GRA']
bright_transitions1=['GRASS2EBF','GRASS2EBF','GRASS2DBF','GRASS2ENF']
data={}
for bt in np.arange(4):
    data[bright_transitions[bt]]=np.swapaxes(xr.open_dataset(idir+'observations/Bright_dTs_ann_2001_2011_FOR2GRA.nc')[bright_transitions[bt]],0,1)
    for seas in ['DJF','JJA']:
        data[bright_transitions1[bt]+'_'+seas]=-np.swapaxes(xr.open_dataset(idir+'observations/OPEN2FOR_'+seas+'_1deg.nc')[bright_transitions1[bt]],0,1)

data['bright_forestmask']=np.swapaxes(xr.open_dataset(idir+'observations/Bright_dTs_ann_FORMASK.nc')['ForMASK'],0,1)
#%%

#LI------------------------------------------------------------ 
data['li_diurnal']=-np.swapaxes(xr.open_dataset(idir+'observations/Li2015_Fig1_NC.nc')['delta_tmax']-xr.open_dataset(idir+'observations/Li2015_Fig1_NC.nc')['delta_tmin'],0,1)
data['li_mean']=-np.swapaxes(xr.open_dataset(idir+'observations/Li2015_Fig1_NC.nc')['delta_tave'],0,1)
data['li_monthly']=-np.swapaxes(xr.open_dataset(idir+'observations/li_monthly.nc')['delta_tave'],1,2)
lats,lons=np.arange(360)/360.*180.-90.,np.arange(720)/720.*360.-180.
data['li_DJF']=xr.DataArray(np.nanmean(data['li_monthly'][[0,1,11],:,:],axis=0),coords=[lats[::-1],lons],dims=['lat','lon'])

data['li_JJA']=xr.DataArray(np.nanmean(data['li_monthly'][[5,6,7],:,:],axis=0),coords=[lats[::-1],lons],dims=['lat','lon'])

#%%
#Duveiller----------------------------------------------------------------------------
data['Duveiller_day']=xr.open_dataset(idir+'observations/Duveiller_LSTday_IGBPgen.nc')['Delta_LSTday'][1,:,:,:] #here, the 1 stands for selecting the transition '13' which means forests to grasses/crops.
data['Duveiller_night']=xr.open_dataset(idir+'observations/Duveiller_LSTnight_IGBPgen.nc')['Delta_LSTnight'][1,:,:,:]
data['duveiller_mean']=cp(data['Duveiller_day'].mean(axis=0))
data['duveiller_mean'].values=np.nanmean((data['Duveiller_day'].mean(axis=0).values,data['Duveiller_night'].mean(axis=0).values),axis=0)
data['duveiller_diurnal']=cp(data['Duveiller_day'].mean(axis=0))
data['duveiller_diurnal'].values=data['Duveiller_day'].mean(axis=0).values-data['Duveiller_night'].mean(axis=0).values
data['duveiller_DJF']=cp(data['Duveiller_day'].mean(axis=0))
data['duveiller_DJF'].values=np.nanmean((data['Duveiller_day'][[0,1,11],:,:].mean(axis=0).values,data['Duveiller_night'][[0,1,11],:,:].mean(axis=0).values),axis=0)
data['duveiller_JJA']=cp(data['Duveiller_day'].mean(axis=0))
data['duveiller_JJA'].values=np.nanmean((data['Duveiller_day'][[5,6,7],:,:].mean(axis=0).values,data['Duveiller_night'][[5,6,7],:,:].mean(axis=0).values),axis=0)


#%%
##regridding for li and bright
#import  scipy
datasets=['EBF2GRA','EBF2GRA','DBF2GRA','ENF2GRA','GRASS2EBF_DJF','GRASS2EBF_DJF','GRASS2DBF_DJF','GRASS2ENF_DJF','GRASS2EBF_JJA','GRASS2EBF_JJA','GRASS2DBF_JJA','GRASS2ENF_JJA','duveiller_mean','duveiller_diurnal','duveiller_DJF','duveiller_JJA','bright_forestmask','li_mean','li_diurnal','li_JJA','li_DJF']
lon1,lat1=np.meshgrid(Sealandmask_lat_lon().lon,np.flipud(Sealandmask_lat_lon().lat))
lats_orig,lons_orig={},{}
for ds in datasets:
    if ds not in ['li_DJF','li_JJA']:
        lats_orig[ds],lons_orig[ds]=np.arange(data[ds].shape[0]),np.arange(data[ds].shape[1])
        regridded[ds]=basemap.interp(data[ds].values,lons_orig[ds],lats_orig[ds],lon1, lat1+90., order=0,masked=False)#bilinear interpolation regridding
        regridded[ds]=ma.masked_invalid(regridded[ds])
        regridded[ds],lon_shifted=basemap.shiftgrid(180,regridded[ds],lonsin=Sealandmask_lat_lon().lon)
    else:
        lat_old, lon_old=np.arange(360)/360.*180.-90,np.arange(720)/720.*360.
        x1,y1=np.meshgrid(lon, lat[::-1])
        regridded[ds]= mpl_toolkits.basemap.interp(data[ds].values, lon_old, lat_old, x1,y1,checkbounds=False, masked=False, order=0)
        regridded[ds]=ma.masked_invalid(regridded[ds])
        regridded[ds],lon_shifted=basemap.shiftgrid(180,regridded[ds],lonsin=Sealandmask_lat_lon().lon)



#Bright:weigh bright data with JSBACH PFTs
tree_fract=xr.open_dataset(idir+'jsbach_T63GR15_11tiles_5layers_1850_sparse_TC1.0.nc')['cover_fract'][0:4,:,:]
weighted_array=np.zeros((4,96,192))
weighted_array1=np.zeros((4,96,192))
weighted_array2=np.zeros((4,96,192))
for ii in np.arange(4):
    weighted_array[ii,:,:]=regridded[datasets[ii]]*tree_fract[ii]
    weighted_array1[ii,:,:]=regridded[datasets[ii+4]]*tree_fract[ii]
    weighted_array2[ii,:,:]=regridded[datasets[ii+8]]*tree_fract[ii]
regridded['bright_weighted_mean']=ma.masked_array(np.nansum(weighted_array,axis=0),regridded['bright_forestmask']==0)
regridded['bright_weighted_DJF']=ma.masked_array(np.nansum(weighted_array1,axis=0),regridded['bright_forestmask']==0)
regridded['bright_weighted_JJA']=ma.masked_array(np.nansum(weighted_array2,axis=0),regridded['bright_forestmask']==0)

if False:
    fig = plt.figure()
    plt.subplot(2,2,1)
    plt.imshow(regridded[ds],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,3)
    plt.imshow(interped_forestloss,vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,2)
    plt.imshow(regridded['alkama_diurnal'],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,4)
#    plt.imshow(obs_mask,vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.show()
#%%
'''
--- SECTION 4: Latitudinal means ------------------------------------------------------------------------------------------
'''

#take only values where at least one of the observational datasets is available. 
obs_mask=np.zeros([len(lat),len(lon)])
obs_mask[regridded['bright_forestmask'].data!=0]=obs_mask[regridded['bright_forestmask'].data!=0]+1
obs_mask[regridded['li_mean']!=0]=obs_mask[regridded['li_mean']!=0]+1
obs_mask[regridded['alkama_mean']!=0]=obs_mask[regridded['alkama_mean']!=0]+1
obs_mask[regridded['duveiller_mean']!=0]=obs_mask[regridded['duveiller_mean']!=0]+1
obs_mask[slm1==0]=0
obs_mask1=cp(obs_mask)

        
data_masked={}
data_masked['mpiesm_local_3of4_JJA']=cp(local_interped['3of4_var169_JJA'])    
data_masked['mpiesm_local_onlyz0_JJA']=cp(local_interped['only_z0_var169_JJA'])   
data_masked['mpiesm_local_onlyalbedo_JJA']=cp(local_interped['only_albedo_var169_JJA'])    
data_masked['mpiesm_local_3of4_DJF']=cp(local_interped['3of4_var169_DJF'])    
data_masked['mpiesm_local_onlyz0_DJF']=cp(local_interped['only_z0_var169_DJF'])  
data_masked['mpiesm_local_onlyalbedo_DJF']=cp(local_interped['only_albedo_var169_DJF'])    
data_masked['mpiesm_local_3of4_diurnal']=cp(local_interped['3of4_diurnal'])    
data_masked['mpiesm_local_onlyz0_diurnal']=cp(local_interped['only_z0_diurnal'])    
data_masked['mpiesm_local_onlyalbedo_diurnal']=cp(local_interped['only_albedo_diurnal'])    
data_masked['mpiesm_local_3of4_mean']=cp(local_interped['3of4_mean'])    
data_masked['mpiesm_local_onlyz0_mean']=cp(local_interped['only_z0_mean'])    
data_masked['mpiesm_local_onlyalbedo_mean']=cp(local_interped['only_albedo_mean'])    

data_masked['li_mean']=cp(regridded['li_mean'])
data_masked['li_diurnal']=cp(regridded['li_diurnal'])
data_masked['li_DJF']=cp(regridded['li_DJF'])
data_masked['li_JJA']=cp(regridded['li_JJA'])
data_masked['alkama_JJA'],data_masked['alkama_DJF']=cp(regridded['alkama_JJA']),cp(regridded['alkama_DJF'])
data_masked['alkama_diurnal']=cp(regridded['alkama_diurnal'])
data_masked['alkama_mean']=cp(regridded['alkama_mean'])
data_masked['bright_weighted_mean']=cp(regridded['bright_weighted_mean'])
data_masked['bright_weighted_DJF']=cp(regridded['bright_weighted_DJF'])
data_masked['bright_weighted_JJA']=cp(regridded['bright_weighted_JJA'])
data_masked['duveiller_mean']=cp(regridded['duveiller_mean'])
data_masked['duveiller_diurnal']=cp(regridded['duveiller_diurnal'])
data_masked['duveiller_DJF']=cp(regridded['duveiller_DJF'])
data_masked['duveiller_JJA']=cp(regridded['duveiller_JJA'])
    
latitudinal={}
for kk in data_masked.keys():
    data_masked[kk][obs_mask1<=0]=np.nan
    latitudinal[kk]=np.nanmean(data_masked[kk],axis=1)
    data_masked[kk]=ma.masked_array(data_masked[kk],obs_mask<=0)

for case in ['mean','diurnal','DJF','JJA']:
    latitudinal['mpiesm_local_residual_'+case]=latitudinal['mpiesm_local_3of4_'+case]-latitudinal['mpiesm_local_onlyalbedo_'+case]-latitudinal['mpiesm_local_onlyz0_'+case]


#weigh alkama data with deforested fraction
latitudinal['alkama_JJA']=np.nanmean(data_masked['alkama_JJA'],axis=1)
latitudinal['alkama_JJA_weighted']=np.nansum(data_masked['alkama_JJA']*interped_forestloss,axis=1)/np.nansum(interped_forestloss,axis=1)

latitudinal['alkama_DJF']=np.nanmean(data_masked['alkama_DJF'],axis=1)
latitudinal['alkama_DJF_weighted']=np.nansum(data_masked['alkama_DJF']*interped_forestloss,axis=1)/np.nansum(interped_forestloss,axis=1)

latitudinal['alkama_diurnal']=np.nanmean(data_masked['alkama_diurnal'],axis=1)
latitudinal['alkama_diurnal_weighted']=np.nansum(data_masked['alkama_diurnal']*interped_forestloss,axis=1)/np.nansum(interped_forestloss,axis=1)

latitudinal['alkama_mean']=np.nanmean(data_masked['alkama_mean'],axis=1)
latitudinal['alkama_mean_weighted']=np.nansum(data_masked['alkama_mean']*interped_forestloss,axis=1)/np.nansum(interped_forestloss,axis=1)

for kk in latitudinal.keys():
    latitudinal[kk][latitudinal[kk]==0]=np.nan

if False:
    plt.plot(latitudinal['alkama_seas_weighted']) #latitudinal means weighted with deforestation fraction
    plt.plot(latitudinal['alkama_seas']) #latitudinal means, uniformly weighted on areas with more than 1% forest loss

    fig = plt.figure()
    plt.subplot(2,2,1)
    plt.imshow(obs_mask,vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,3)
    plt.imshow(data_masked['li_DJF'],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,2)
    plt.imshow(data_masked['li_mean'],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.subplot(2,2,4)
    plt.imshow(regridded['duveiller_DJF'],vmin=-3,vmax=3, interpolation= 'None')
    plt.colorbar()
    plt.show()

    
    fig = plt.figure()
    plt.plot(latitudinal['duveiller_mean'],label='duveiller')
    plt.plot(latitudinal['li_mean'],label='li')
    plt.plot(latitudinal['bright_weighted_mean'],label='bright')
    plt.plot(latitudinal['alkama_mean'],label='alkama')
    plt.legend()
    pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/observations_lines_test_roughnesspaper.png'
    fig.savefig(pngfile,dpi=300, bbox_inches='tight')
      
##make running mean over 2 latitudes each to smooth out  #only works for runningmeans=2! Badly coded here.
runmean={}
runningmeans=[2]
for rr in runningmeans:
    for item in latitudinal.keys():
        runmean[item]=np.zeros(len(lat))
        for yy in np.arange(len(lat)-rr)+1:
            if runningmeans==[2]:
                runmean[item][yy]=(0.5*latitudinal[item][yy-1]+latitudinal[item][yy]+0.5*latitudinal[item][yy+1])/2

#minimum and maximum for envelope (here only for satellite-based approaches)
max_min={}
for case in ['mean','diurnal','DJF','JJA']:
    max_min['max_'+case]=np.nanmax(np.array((latitudinal['alkama_'+case],latitudinal['li_'+case],latitudinal['duveiller_'+case])),axis=0)
    max_min['min_'+case]=np.nanmin(np.array((latitudinal['alkama_'+case],latitudinal['li_'+case],latitudinal['duveiller_'+case])),axis=0)


#%%
'''
--- SECTION 5: SAVE DATA------------------------------------------------------------------------------------------
'''

np.save('/home/jwi/paper_jwi/2018_paper05/data/save/latitudinal',latitudinal)
np.save('/home/jwi/paper_jwi/2018_paper05/data/save/maps_mean_diurnal_DJF_JJA',data_masked)

#%%
'''
--- SECTION 6: PLOT ------------------------------------------------------------------------------------------
'''

#---------PREPARE-----------------
#get colorbar
os.chdir('/home/jwi/paper_jwi/2017_paper03/analysis/scripts')
fileObject = open('bwr_jwi','r')
cmap_bwr_jwi = pickle.load(fileObject)
fileObject.close()

bounds=(-6,-5,-4,-3,-2,-1.5,-1,-0.5,-0.1,0.1,0.5,1,1.5,2,3.0,4,5,6)

cmap_bwr_jwi.set_bad('grey',0.7)
norm=mpl.colors.BoundaryNorm(bounds, cmap_bwr_jwi.N)

#lats and lons
offset_lon,offset_lat=-1,1
meshlon=lon+offset_lon
meshlat=lat+offset_lat

plotmax=0.95*max(bounds)

meshlon, meshlat= np.meshgrid(meshlon, meshlat)
meshlon_li, meshlat_li= np.meshgrid(np.arange(-180,180,1),np.arange(-90,90,1))
meshlon_alkama, meshlat_alkama= np.meshgrid(np.arange(-180,180,4),np.arange(-90,90,4))
#
#itemlist_JJA=['mpiesm_local_3of4_JJA','mpiesm_local_onlyz0_JJA','mpiesm_local_onlyalbedo_JJA','mpiesm_local_residual_JJA','bright_weighted_JJA']
#itemlist_DJF=['mpiesm_local_3of4_DJF','mpiesm_local_onlyz0_DJF','mpiesm_local_onlyalbedo_DJF','mpiesm_local_residual_DJF','bright_weighted_DJF']
#itemlist_diurnal=['mpiesm_local_3of4_diurnal','mpiesm_local_onlyz0_diurnal','mpiesm_local_onlyalbedo_diurnal','mpiesm_local_residual_diurnal']
#itemlist_mean=['mpiesm_local_3of4_mean','mpiesm_local_onlyz0_mean','mpiesm_local_onlyalbedo_mean','mpiesm_local_residual_mean','bright_weighted_mean']

itemlist_JJA=['mpiesm_local_3of4_JJA','mpiesm_local_onlyz0_JJA','mpiesm_local_onlyalbedo_JJA','bright_weighted_JJA']
itemlist_DJF=['mpiesm_local_3of4_DJF','mpiesm_local_onlyz0_DJF','mpiesm_local_onlyalbedo_DJF','bright_weighted_DJF']
itemlist_diurnal=['mpiesm_local_3of4_diurnal','mpiesm_local_onlyz0_diurnal','mpiesm_local_onlyalbedo_diurnal']
itemlist_mean=['mpiesm_local_3of4_mean','mpiesm_local_onlyz0_mean','mpiesm_local_onlyalbedo_mean','bright_weighted_mean']

labellist=['all','only roughness','only albedo','Bright et al. (2017)']
#labellist=['deforestation','roughness','albedo','residual','Fluxnet']


#colors=['black','limegreen','royalblue','violet','darkgrey','darkgrey','darkgrey']
colors=['black','limegreen','violet','darkgrey','darkgrey','darkgrey']
zorders=[4,3,2,1,0,0,0,0]

#stippling for number of observation datasets:
markers=['x','+','_']
x,y={},{}
m = Basemap(projection='robin',lon_0=0,resolution='c')
for ii in np.arange(3):
    x[str(ii)],y[str(ii)]=m(lon[np.where(np.all(np.array((obs_mask==ii,slm1==1)),axis=0))[1]]-0.2,lat[np.where(np.all(np.array((obs_mask==ii,slm1==1)),axis=0))[0]]+0.2)
 

#%%
#LATITUDINAL PLOT MPIESM VERSUS OBS, FOR MEAN, DIURNAL CYCLE, DJF AND JJA
fig = plt.figure(figsize=(18,12))
gs= gridspec.GridSpec(1, 5, width_ratios=(5,5,5,5,5))
#
axes = plt.subplot(gs[0])
plt.annotate('a) Annual mean', xy=(0.025, 0.965), xycoords='axes fraction',fontsize=23)
for ii in np.arange(len(itemlist_mean)):
        plt.plot(latitudinal[itemlist_mean[ii]],lat,zorder=zorders[ii],linewidth=4, color=colors[ii])

plt.fill_betweenx(lat, max_min['min_mean'], max_min['max_mean'],color='black',alpha=0.15,label='remote sensing')

plt.xlim((-2.5,5.6))
plt.ylim((-39,78))
plt.xticks(fontsize=23)
plt.yticks(fontsize=23)
plt.axvline(x=0, ymin=-45,ymax=65, c='grey',zorder=0)
plt.axhline(y=60, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=40, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=20, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=0, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=-20, c='grey',linestyle=':',linewidth=1,zorder=0)

plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=23 )
#plt.ylabel('latitude [$^{\circ}$]',fontsize=23)
plt.ylabel('latitude ',fontsize=23)


axes = plt.subplot(gs[1])
plt.annotate('b) Diurnal', xy=(0.025, 0.965), xycoords='axes fraction',fontsize=23)
for ii in np.arange(len(itemlist_diurnal)):
    plt.plot(latitudinal[itemlist_diurnal[ii]],lat,zorder=zorders[ii],linewidth=4, color=colors[ii])

plt.fill_betweenx(lat, max_min['min_diurnal'], max_min['max_diurnal'],color='black',alpha=0.15,label='Satellite')


plt.xlim((-2.5,5.6))
plt.ylim((-39,78))
plt.xticks(fontsize=23)
plt.yticks(fontsize=23)
plt.axvline(x=0, ymin=-45,ymax=65, c='grey',zorder=0)
plt.axhline(y=60, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=40, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=20, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=0, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=-20, c='grey',linestyle=':',linewidth=1,zorder=0)

plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=23 )
#plt.ylabel('latitude [$^{\circ}$N]',fontsize=23)
axes.set_yticks([])

axes = plt.subplot(gs[2])
plt.annotate('c) DJF', xy=(0.025, 0.965), xycoords='axes fraction',fontsize=23)
#plt.fill_betweenx(lat,min_obs, max_obs,color='black',alpha=0.15,label='Observations')
for ii in np.arange(len(itemlist_DJF)):
    plt.plot(latitudinal[itemlist_DJF[ii]],lat,zorder=zorders[ii],linewidth=4, color=colors[ii])

plt.fill_betweenx(lat, max_min['min_DJF'], max_min['max_DJF'],color='black',alpha=0.15,label='Satellite')

plt.xlim((-2.5,5.6))
plt.ylim((-39,78))
plt.xticks(fontsize=23)
plt.yticks(fontsize=23)
plt.axvline(x=0, ymin=-45,ymax=65, c='grey',zorder=0)
plt.axhline(y=60, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=40, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=20, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=0, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=-20, c='grey',linestyle=':',linewidth=1,zorder=0)

plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=23 )
axes.set_yticks([])


axes = plt.subplot(gs[3])
plt.annotate('d) JJA', xy=(0.025, 0.965), xycoords='axes fraction',fontsize=23)
for ii in np.arange(len(itemlist_JJA)):
        if ii<5:
            plt.plot(latitudinal[itemlist_JJA[ii]],lat,zorder=zorders[ii],label=labellist[ii],linewidth=4, color=colors[ii])
        else:
            plt.plot(latitudinal[itemlist_JJA[ii]],lat,zorder=zorders[ii],linewidth=4, color=colors[ii])

plt.fill_betweenx(lat, max_min['min_JJA'], max_min['max_JJA'],color='black',alpha=0.15,label='Satellite')


plt.xlim((-2.5,5.6))
plt.ylim((-39,78))
plt.xticks(fontsize=23)
plt.yticks(fontsize=23)
plt.axvline(x=0, ymin=-45,ymax=65, c='grey',zorder=0)
plt.axhline(y=60, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=40, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=20, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=0, c='grey',linestyle=':',linewidth=1,zorder=0)
plt.axhline(y=-20, c='grey',linestyle=':',linewidth=1,zorder=0)

plt.xlabel('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=23 )
axes.set_yticks([])

#leg=plt.legend(fontsize=18, loc=3)
#leg.get_frame().set_linewidth(0.0)

h,l = axes.get_legend_handles_labels()
laxes = plt.subplot(gs[4])
laxes.legend(h,l, borderaxespad=0, fontsize=18)
laxes.axis("off")

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/local_mpiesm_vs_obs_latitudinal.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/local_mpiesm_vs_obs_latitudinal.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=200, bbox_inches='tight')
os.system('pdfcrop ' +pdffile +' '+pdffile)
plt.close()



#%% Maps mean
fig = plt.figure(figsize=(20,22))
gs= gridspec.GridSpec(5, 2,height_ratios=(40,40,40,40,1.5))

axes = plt.subplot(gs[0,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['li_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Li \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[0,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['alkama_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Alkama \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['bright_weighted_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Bright \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['duveiller_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Duveiller \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('MPI-ESM local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyz0_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('roughness, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyalbedo_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('albedo, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_mean']-data_masked['mpiesm_local_onlyz0_mean']-data_masked['mpiesm_local_onlyalbedo_mean'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('residual, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[4,:])
cb=mpl.colorbar.ColorbarBase(axes, cmap=cmap_bwr_jwi, norm=norm, ticks=bounds,spacing='uniform', boundaries=bounds, orientation='horizontal')
cb.ax.tick_params(labelsize=26)
cb.set_label('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=26)

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_mean.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_mean.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=300, bbox_inches='tight')
plt.close()
#os.system('pdfcrop ' +pfile +' '+pfile)

#%% Maps diurnal
fig = plt.figure(figsize=(20,22))
gs= gridspec.GridSpec(5, 2,height_ratios=(40,40,40,40,1.5))

axes = plt.subplot(gs[0,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['li_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Li \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[0,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['alkama_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Alkama \n ',fontsize=26)
local_text.set_verticalalignment('center')
#
#
#axes = plt.subplot(gs[1,0])
##plt.annotate('c)', xy=(0.05, 0.9), xycoords='axes fraction',fontsize=26)
#m = Basemap(projection='robin',lon_0=0,resolution='c')
#m.drawcoastlines(linewidth=0.5)
#m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
#plot=m.pcolormesh(meshlon, meshlat, data_masked['bright_weighted_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
##for ii in np.arange(1):
##    m.scatter(x[str(ii)],y[str(ii)],marker='.',s=6*(3-ii),c='black',linewidth=0.2,alpha=0.6)
#local_text=axes.set_title('Bright \n ',fontsize=26)
#local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['duveiller_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Duveiller \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('MPI-ESM local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyz0_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('roughness, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyalbedo_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('albedo, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_diurnal']-data_masked['mpiesm_local_onlyz0_diurnal']-data_masked['mpiesm_local_onlyalbedo_diurnal'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('residual, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[4,:])
cb=mpl.colorbar.ColorbarBase(axes, cmap=cmap_bwr_jwi, norm=norm, ticks=bounds,spacing='uniform', boundaries=bounds, orientation='horizontal')
cb.ax.tick_params(labelsize=26)
cb.set_label('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=26)

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_diurnal.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_diurnal.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=200, bbox_inches='tight')
plt.close()

#%% Maps DJF
fig = plt.figure(figsize=(20,22))
gs= gridspec.GridSpec(5, 2,height_ratios=(40,40,40,40,1.5))

axes = plt.subplot(gs[0,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['li_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Li \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[0,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['alkama_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Alkama \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['bright_weighted_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Bright \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['duveiller_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Duveiller \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('MPI-ESM local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyz0_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('roughness, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyalbedo_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('albedo, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_DJF']-data_masked['mpiesm_local_onlyz0_DJF']-data_masked['mpiesm_local_onlyalbedo_DJF'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('residual, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[4,:])
cb=mpl.colorbar.ColorbarBase(axes, cmap=cmap_bwr_jwi, norm=norm, ticks=bounds,spacing='uniform', boundaries=bounds, orientation='horizontal')
cb.ax.tick_params(labelsize=26)
cb.set_label('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=26)

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_DJF.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_DJF.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=200, bbox_inches='tight')
plt.close()
#os.system('pdfcrop ' +pfile +' '+pfile)

#%% Maps JJA
fig = plt.figure(figsize=(20,22))
gs= gridspec.GridSpec(5, 2,height_ratios=(40,40,40,40,1.5))

axes = plt.subplot(gs[0,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['li_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Li \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[0,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['alkama_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Alkama \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['bright_weighted_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Bright \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[1,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['duveiller_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('Duveiller \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('MPI-ESM local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[2,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyz0_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('roughness, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,0])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_onlyalbedo_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('albedo, local  \n ',fontsize=26)
local_text.set_verticalalignment('center')
#

axes = plt.subplot(gs[3,1])
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
m.drawparallels(np.arange(-20,61,20),labels=[0,1,0,0],fontsize=20, color='grey')
plot=m.pcolormesh(meshlon, meshlat, data_masked['mpiesm_local_3of4_JJA']-data_masked['mpiesm_local_onlyz0_JJA']-data_masked['mpiesm_local_onlyalbedo_JJA'], latlon=True, cmap=cmap_bwr_jwi, norm=norm,vmin=-plotmax, vmax=plotmax,rasterized=True,zorder=1)
local_text=axes.set_title('residual, local \n ',fontsize=26)
local_text.set_verticalalignment('center')
#


axes = plt.subplot(gs[4,:])
cb=mpl.colorbar.ColorbarBase(axes, cmap=cmap_bwr_jwi, norm=norm, ticks=bounds,spacing='uniform', boundaries=bounds, orientation='horizontal')
cb.ax.tick_params(labelsize=26)
cb.set_label('$\Delta$ T$_{\mathrm{surf}}$ [K]',fontsize=26)

plt.tight_layout()

pngfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_JJA.png'
pdffile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/obs_maps_JJA.pdf'
fig.savefig(pngfile,dpi=300, bbox_inches='tight')
fig.savefig(pdffile,dpi=200, bbox_inches='tight')
plt.close()
