'''
Created on Jan, 2019

@author: jwi

This script plots the veg_ratio_max used in our simulations. This is the fraction within each grid cell that is covered by the vegetation tiles, the rest is bare soil.
'''
import os
import numpy as np
#import Nio
import xarray as xr
from copy import deepcopy as cp

#data analysis
#import stat_test_gbw_rev3 #significance test (t-test accounting for lag-1 autocorrelation)

#import sys
#import imp
#imp.reload(sys.modules['separate_local_nonlocal3'])
from separate_local_nonlocal3 import separate_local_nonlocal
from Sealandmask_lat_lon import Sealandmask_lat_lon
from func_metrics import calc_landmean

from copy import deepcopy as dcp

#plot
import pickle #for importing colorbar
import matplotlib as mpl
import matplotlib.pyplot as plt
from matplotlib import gridspec
from mpl_toolkits.basemap import Basemap
import numpy.ma as ma
#
import matplotlib.cm as cm
#imp.reload(sys.modules['Sealandmask_lat_lon'])

'''
--- SECTION 1: load netcdf data ------------------------------------------------------------------------------------------
'''
idir='/home/jwi/model_stuff/masks/'
veg_ratio_max=np.squeeze(xr.open_dataset(idir+'jsbach_T63GR15_11tiles_1850.nc')['veg_ratio_max'])
slm,lat,lon,slm1=Sealandmask_lat_lon().slm,Sealandmask_lat_lon().lat,Sealandmask_lat_lon().lon,Sealandmask_lat_lon().slm1
veg_ratio_max1=ma.masked_array(veg_ratio_max,slm1==0)
#=cp(veg_ratio_max)
#veg_ratio_max1[slm==0.]=0.

               
slm_3of4=dcp(slm1)
slm_3of4[::2,::2]=0
#plt.imshow(slm_3of4)        
slm_3of4_masked=ma.masked_array(slm_3of4,slm_3of4==0)
#%%
'''
--- SECTION 2: PLOT MAPS------------------------------------------------------------------------------------------
'''
cmap=cm.get_cmap('YlGn')
bounds=np.arange(0,1.1,0.1)
cmap.set_bad('grey',0.7)
norm=mpl.colors.BoundaryNorm(bounds, cmap.N)

#lats and lons
meshlon=lon-1.2
meshlat=lat+0.6

#plotmax=0.95*max(bounds)

meshlon, meshlat= np.meshgrid(meshlon, meshlat)

np.save('/home/jwi/paper_jwi/2017_paper03/2017_paper03_johannes_winckler_save/data/fig_S1/veg_ratio_max',veg_ratio_max)



#%%
#---------PLOT-----------------

fig = plt.figure(figsize=(15,6))
gs= gridspec.GridSpec(2,2, height_ratios=(25, 1))
#
axes = plt.subplot(gs[0,0])
plt.title('Vegetated areas', fontsize=20)
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
plot=m.pcolormesh(meshlon, meshlat, veg_ratio_max1, latlon=True, cmap=cmap, norm=norm,vmin=0, vmax=1,rasterized=True,zorder=1)

axes = plt.subplot(gs[0,1])
plt.title('Change boxes', fontsize=20)
m = Basemap(projection='robin',lon_0=0,resolution='c')
m.drawcoastlines(linewidth=0.5)
plot=m.pcolormesh(meshlon, meshlat, slm_3of4_masked, latlon=True, cmap=cmap, norm=norm,vmin=0, vmax=1,rasterized=True,zorder=1)

axes = plt.subplot(gs[1,0])
cb=mpl.colorbar.ColorbarBase(axes, cmap=cmap, norm=norm, ticks=bounds,spacing='uniform', boundaries=bounds, orientation='horizontal')
cb.ax.tick_params(labelsize=20)
cb.set_label('fraction of grid box []',fontsize=21)

plt.tight_layout()

pfile='/home/jwi/paper_jwi/2018_paper05/analysis/plots/veg_ratio_max_S1.pdf'
fig.savefig(pfile,dpi=180, bbox_inches='tight')
plt.close()
